@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 #-*- coding: latin-1 -*-
 
-# mdt25.py 081204
-# Copyright 2008 Gregorio Díaz-Marta Mateos
+# mdt25.py 090106
+# Copyright 2008, 2009 Gregorio Díaz-Marta Mateos
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -95,7 +95,7 @@ def processargs(args):
 
     return x1, y1, x2, y2, dstname
 
-def download_mdt25(x1, y1, x2, y2, name=None):
+def download_mdt25(x1, y1, x2, y2, name=None, reporthook=None):
     """Download a mdt25 raster file from IDEE WCS.
 
     Format is AsciiGrid with float32 pixel values and EPSG:23030 srs but
@@ -120,11 +120,12 @@ def download_mdt25(x1, y1, x2, y2, name=None):
           'EXCEPTIONS=XML'
 
     url = url % (x1, y1, x2, y2)
-    urllib.urlretrieve(url, name)
+    urllib.urlretrieve(url, name, reporthook)
     if gdal_available:
         add_srs(name, 'EPSG:23030')
 
-def download_mdt25_mosaic(x1, y1, x2, y2, name, tilesize=25000):
+def download_mdt25_mosaic(x1, y1, x2, y2, name, tilesize=25000,
+                          reporthook=None):
     """Download a mdt25 mosaic from IDEE WCS.
 
     Returns a list of file names. See download_mdt25 for details.
@@ -137,10 +138,16 @@ def download_mdt25_mosaic(x1, y1, x2, y2, name, tilesize=25000):
         for yy1 in range(y1, y2, tilesize):
            yy2 = min(y2, yy1 + tilesize)
            tilename = add_coords(name, xx1, yy1)
-           download_mdt25(xx1, yy1, xx2, yy2, tilename)
+           download_mdt25(xx1, yy1, xx2, yy2, tilename, reporthook)
            names.append(tilename)
     return names
 
+def reporthook(blockcount, blocksize, filesize):
+    if blockcount == 0:
+        print 'Downloading %s bytes' % filesize
+    else:
+        print 'Block #%s (%s bytes)' % (blockcount, blocksize)
+
 
 if __name__ == '__main__':
     try:
@@ -153,9 +160,10 @@ if __name__ == '__main__':
     dx = x2 - x1
     dy = y2 - y1
     if max(dx, dy) > 35000:
-        names = download_mdt25_mosaic(x1, y1, x2, y2, dstname, tilesize=2500)
+        names = download_mdt25_mosaic(x1, y1, x2, y2, dstname,
+                                      tilesize=25000, reporthook=reporthook)
     else:
-        download_mdt25(x1, y1, x2, y2, dstname)
+        download_mdt25(x1, y1, x2, y2, dstname, reporthook=reporthook)
         names = [dstname]
 
     if gdal_available:
